@@ -1,5 +1,4 @@
 import os
-import signal
 import threading
 import time
 from platform import python_version
@@ -24,6 +23,7 @@ class Reporter:
         self.config = config
         self._thread = None
         self._running = False
+        self._lock = threading.Lock()
         self._stopevent = threading.Event()
         self.collectors: List[Collector] = []
         self.adapters: List[Adapter] = []
@@ -48,30 +48,38 @@ class Reporter:
             self.collectors.append(adapter.metrics_collector)
 
     def start(self):
+        if not self.config.is_enabled:
+            logger.info("Reporter not started: API_BASE_URL not set")
+            return
+
+        if self.config["RUNTIME_CONTAINER"] is None:
+            logger.info("Reporter not started: unknown runtime container")
+            return
+
+        if self.config["RUNTIME_CONTAINER"].is_release_instance:
+            logger.info("Reporter not started: in a build process")
+            return
+
         logger.info(f"Starting reporter for process {self.pid}")
         self._thread = threading.Thread(target=self._run_loop, daemon=True)
         self._thread.start()
-        self._running = True
 
     def ensure_running(self):
         try:
-            if not self.is_running:
-                return self.start()
+            with self._lock:
+                if not self.is_running:
+                    return self.start()
         except Exception as e:
             logger.warning(f"{e.args} - No reporter has initiated")
             pass
 
-    def signal_handler(self, signum, frame):
+    def stop(self):
         self._stopevent.set()
         self._running = False
 
     @property
     def is_running(self):
-        if self._thread and self._thread.is_alive():
-            self._running = True
-        else:
-            self._running = False
-        return self._running
+        return self._thread and self._thread.is_alive()
 
     @property
     def pid(self) -> int:
@@ -79,8 +87,13 @@ class Reporter:
 
     def _run_loop(self):
         while self.is_running:
-            self._report_metrics()
+            # NOTE: we used to report metrics immediately after the process
+            # started, but this caused issues with Celery and Celery Beat
+            # when TRACK_BUSY_JOBS was enabled.
+            # Instead, we now wait for the first interval to pass before
+            # reporting metrics.
             time.sleep(self.config["REPORT_INTERVAL_SECONDS"])
+            self._report_metrics()
 
             if self._stopevent.is_set():
                 break
@@ -123,4 +136,3 @@ class Reporter:
 
 
 reporter = Reporter(config=config)
-signal.signal(signal.SIGTERM, reporter.signal_handler)
